"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatter = exports.originInputs = void 0;
const common_1 = require("@tencent-serverless-framework/common");
const fs = require("fs");
const path = require("path");
/** 用于获取证书文件信息 */
function getCertPathContent(target) {
    let content = '';
    try {
        const stat = fs.statSync(target);
        if (stat.isFile()) {
            if (path.isAbsolute(target)) {
                content = fs.readFileSync(target, 'base64');
            }
            else {
                content = fs.readFileSync(path.join(process.cwd(), target), 'base64');
            }
        }
    }
    catch (e) {
        // target is string just return
        content = target;
    }
    return content;
}
/**
 * 格式化证书
 * @param {object} certInfo cert info
 */
function certInputs(certInfo) {
    var _a;
    if (certInfo.certId) {
        return {
            certId: certInfo.certId,
        };
    }
    return {
        certificate: getCertPathContent(certInfo.certificate),
        privateKey: getCertPathContent(certInfo.privateKey),
        message: (_a = certInfo.remarks) !== null && _a !== void 0 ? _a : '',
    };
}
/** 格式化 CDN 源信息 */
function originInputs(origin) {
    const originInfo = {
        origins: origin.origins,
        originType: origin.originType,
        originPullProtocol: origin.originPullProtocol,
        serverName: origin.serverName,
    };
    if (origin.originType === 'cos') {
        return {
            ...originInfo,
            serverName: origin.origins[0],
            cosPrivateAccess: 'off',
        };
    }
    if (origin.originType === 'domain') {
        if (origin.backupOrigins) {
            return {
                ...originInfo,
                backupOrigins: origin.backupOrigins,
                backupOriginType: origin.backupOriginType,
                backupServerName: origin.backupServerName,
            };
        }
    }
    return originInfo;
}
exports.originInputs = originInputs;
/** DeployInputs 转 AddCdnDomainRequest */
function deployInputs(inputs) {
    var _a, _b, _c;
    if (inputs.https) {
        const hs = inputs.https;
        inputs.https = {
            switch: (_a = hs.switch) !== null && _a !== void 0 ? _a : 'on',
            http2: hs.http2 || 'off',
            ocspStapling: hs.ocspStapling || 'off',
            verifyClient: hs.verifyClient || 'off',
            certInfo: certInputs(hs.certInfo),
        };
    }
    if (inputs.forceRedirect && inputs.https) {
        inputs.forceRedirect = {
            switch: (_b = inputs.forceRedirect.switch) !== null && _b !== void 0 ? _b : 'on',
            redirectStatusCode: (_c = inputs.forceRedirect.redirectStatusCode) !== null && _c !== void 0 ? _c : 301,
            redirectType: 'https',
        };
    }
    return common_1.pascalCaseProperty(inputs);
}
exports.formatter = {
    originInputs,
    certInputs,
    deployInputs,
};
